@@ -25,6 +25,9 @@ public slots:
     bool widgetInstalled() const;
     bool xTubeInstalled() const;
     void setMediaPlayer(const QString &player);
+    QString getMediaPlayer() const { return mediaPlayer; }
+    void doNotDisturb(bool videoPlaying);
+    void keepDisplayOn();
     void getMediaPlayerFromDB();
     QStringList getProxyFromDB() const;
     void toggleState();
